@@ -176,7 +176,7 @@ class AdditionalMagicalSecrets(Feature):
     name = "Additional Magical Secrets"
     source = "Bard (College of Lore)"
 
-    
+
 class PeerlessSkill(Feature):
     """Starting at 14th level, when you make an ability check, you can expend one
     use of Bardic Inspiration. Roll a Bardic Inspiration die and add the number
@@ -245,7 +245,7 @@ class MantleOfInspiration(Feature):
         level = self.owner.Bard.level
         hp = 5 + 3*(level // 5)
         return self._name + " ({:d}HP)".format(hp)
-    
+
 
 class EnthrallingPerformance(Feature):
     """Starting at 3rd level, you can charge your performance with seductive, fey
@@ -383,7 +383,7 @@ class PsychicBlades(Feature):
     so only once per round on your turn. The psychic damage increases when you
     reach certain levels in this class, increasing to 3d6 at 5th level, 5d6
     at 10th level, and 8d6 at 15th level.
-    
+
     """
     _name = "Psychic Blades"
     source = "Bard (College of Whispers)"
@@ -402,15 +402,15 @@ class PsychicBlades(Feature):
 
 
 class WordsOfTerror(Feature):
-    """At 3rd level, you learn to infuse innocent-seeming words with an insidious
-    magic that can inspire terror. If you speak to a humanoid alone for at
-    least 1 minute, you can attempt to seed paranoia in its mind. At the end of
-    the conversation, the target must succeed on a Wisdom saving throw against
-    your spell save DC or be frightened of you or another creature ofyour
-    choice. The target is frightened in this way for 1 hour, until it is at-
-    tacked or damaged, or until it witnesses its allies being attacked or
+    """At 3rd level, you learn to infuse innocent-seeming words with
+    an insidious magic that can inspire terror. If you speak to a humanoid alone
+    for at least 1 minute, you can attempt to seed paranoia in its mind. At
+    the end of the conversation, the target must succeed on a Wisdom saving
+    throw against your spell save DC or be frightened of you or another creature
+    of your choice. The target is frightened in this way for 1 hour, until it is
+    attacked or damaged, or until it witnesses its allies being attacked or
     damaged.
-    
+
     If the target succeeds on its saving throw, the target has no hint that you
     tried to frighten it. Once you use this feature, you can't use it again
     until you finish a short or long rest.
