@@ -35,3 +35,15 @@ class Actor(Feature):
     """
     name = "Actor"
     source = "Feats"
+
+
+class Resilient(Feature):
+    """ Choose one ability score. You gain the following benefits:
+
+    -- Increase the chosen ability score by 1, to a maximum of 20.
+
+    -- You gain proficiency in saving throws using the chosen ability.
+    """
+    name = 'Resilient'
+    source = "Feats"
+    needs_implementation = True
